package xyz.leomurca.csgomatches.data.remote

import kotlinx.serialization.json.Json
import xyz.leomurca.csgomatches.data.model.ErrorDto
import xyz.leomurca.csgomatches.data.model.MatchDto
import xyz.leomurca.csgomatches.data.model.TeamDetailsDto
import xyz.leomurca.csgomatches.data.source.MatchDataSource
import xyz.leomurca.csgomatches.domain.model.Resource

class MatchRemoteDataSourceImpl(
    private val matchesApiService: MatchesApiService,
    private val json: Json
) : MatchDataSource {
    override suspend fun upcomingMatches(page: Int): Resource<List<MatchDto>> {
        return try {
            val response = matchesApiService.upcomingMatches(page = page)

            if (response.isSuccessful) {
                Resource.Success(response.body() ?: throw Exception("Empty response body"))
            } else {
                val errorBody = response.errorBody()?.string() ?: ""
                val networkError = json.decodeFromString<ErrorDto>(errorBody)
                Resource.Error(networkError.message)
            }
        } catch (e: Exception) {
            Resource.Error(e.message.toString())
        }
    }

    override suspend fun teamDetails(teamId: String): Resource<List<TeamDetailsDto>> {
        return try {
            val response = matchesApiService.teamDetails(teamId)

            if (response.isSuccessful) {
                Resource.Success(response.body() ?: throw Exception("Empty response body"))
            } else {
                val errorBody = response.errorBody()?.string() ?: ""
                val networkError = json.decodeFromString<ErrorDto>(errorBody)
                Resource.Error(networkError.message)
            }
        } catch (e: Exception) {
            Resource.Error(e.message.toString())
        }
    }
}