package xyz.leomurca.csgomatches.data.repository

import androidx.compose.foundation.pager.PageSize
import kotlinx.coroutines.CoroutineDispatcher
import kotlinx.coroutines.withContext
import xyz.leomurca.csgomatches.data.mapper.toDomain
import xyz.leomurca.csgomatches.data.source.MatchDataSource
import xyz.leomurca.csgomatches.di.AppDispatchers
import xyz.leomurca.csgomatches.di.Dispatcher
import xyz.leomurca.csgomatches.domain.model.Match
import xyz.leomurca.csgomatches.domain.model.Resource
import xyz.leomurca.csgomatches.domain.model.Team
import xyz.leomurca.csgomatches.domain.repository.MatchRepository

class MatchRepositoryImpl(
    @Dispatcher(AppDispatchers.IO) private val ioDispatcher: CoroutineDispatcher,
    private val matchRemoteDataSource: MatchDataSource
) : MatchRepository {
    override suspend fun upcomingMatches(page: Int): Resource<List<Match>> {
        return withContext(ioDispatcher) {
            when (val result = matchRemoteDataSource.upcomingMatches(page)) {
                is Resource.Success -> Resource.Success(result.data.map { it.toDomain() })
                is Resource.Error -> Resource.Error(result.message)
            }
        }
    }

    override suspend fun teamDetails(teamId: String): Resource<List<Team>> {
        return withContext(ioDispatcher) {
            when (val result = matchRemoteDataSource.teamDetails(teamId)) {
                is Resource.Success -> Resource.Success(result.data.map { it.toDomain() })
                is Resource.Error -> Resource.Error(result.message)
            }
        }
    }
}