package xyz.leomurca.csgomatches.di

import com.jakewharton.retrofit2.converter.kotlinx.serialization.asConverterFactory
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent
import kotlinx.coroutines.CoroutineDispatcher
import kotlinx.serialization.json.Json
import okhttp3.Interceptor
import retrofit2.Retrofit
import xyz.leomurca.csgomatches.data.remote.MatchesApiService
import javax.inject.Singleton
import okhttp3.MediaType.Companion.toMediaType
import okhttp3.OkHttpClient
import xyz.leomurca.csgomatches.BuildConfig
import xyz.leomurca.csgomatches.data.remote.AuthorizationInterceptor
import xyz.leomurca.csgomatches.data.remote.MatchRemoteDataSourceImpl
import xyz.leomurca.csgomatches.data.repository.MatchRepositoryImpl
import xyz.leomurca.csgomatches.data.source.MatchDataSource
import xyz.leomurca.csgomatches.domain.repository.MatchRepository

@Module
@InstallIn(SingletonComponent::class)
internal object NetworkModule {

    @Provides
    @Singleton
    fun providesNetworkJson(): Json = Json {
        ignoreUnknownKeys = true
        isLenient = true
        explicitNulls = false
    }

    @Provides
    @Singleton
    fun provideAuthorizationInterceptor(): Interceptor {
        return AuthorizationInterceptor(BuildConfig.ACCESS_TOKEN)
    }

    @Provides
    @Singleton
    fun provideOkHttpClient(authInterceptor: Interceptor): OkHttpClient {
        return OkHttpClient.Builder()
            .addInterceptor(authInterceptor)
            .build()
    }

    @Provides
    @Singleton
    fun provideRetrofit(json: Json, okHttpClient: OkHttpClient): Retrofit {
        val contentType = "application/json".toMediaType()
        return Retrofit.Builder()
            .baseUrl(BuildConfig.API_BASE_URL)
            .client(okHttpClient)
            .addConverterFactory(json.asConverterFactory(contentType))
            .build()
    }

    @Provides
    @Singleton
    fun provideMatchesApiService(retrofit: Retrofit): MatchesApiService {
        return retrofit.create(MatchesApiService::class.java)
    }

    @Provides
    @Singleton
    fun provideMatchRemoteDataSource(
        matchesApiService: MatchesApiService,
        json: Json
    ): MatchDataSource {
        return MatchRemoteDataSourceImpl(matchesApiService, json)
    }

    @Provides
    @Singleton
    fun providesMatchRepository(
        @Dispatcher(AppDispatchers.IO) ioDispatcher: CoroutineDispatcher,
        matchRemoteDataSource: MatchDataSource
    ): MatchRepository {
        return MatchRepositoryImpl(ioDispatcher, matchRemoteDataSource)
    }
}